@@ -1,9 +1,9 @@
 import os
 
-from pyqtgraph import QtCore, QtGui
-QtWidgets = QtGui
-Signal = QtCore.pyqtSignal
-Slot = QtCore.pyqtSlot
+from qtpy import QtCore, QtGui, QtWidgets
+
+Signal = QtCore.Signal
+Slot = QtCore.Slot
 
 from pyqtgraph.flowchart import Flowchart as pgFlowchart, Node as pgNode
 Flowchart = pgFlowchart
