@@ -8,7 +8,7 @@ import copy as cp
 
 import numpy as np
 from functools import reduce
-from typing import List, Tuple, Dict, Sequence, Union, Any, Iterator
+from typing import List, Tuple, Dict, Sequence, Union, Any, Iterator, Optional
 
 from plottr.utils import num, misc
 
@@ -23,21 +23,21 @@ __license__ = 'MIT'
 # TODO: feature to compare if datadicts are equal not fully tested yet.
 
 
-def is_meta_key(key):
+def is_meta_key(key: str) -> bool:
     if key[:2] == '__' and key[-2:] == '__':
         return True
     else:
         return False
 
 
-def meta_key_to_name(key):
+def meta_key_to_name(key: str) -> str:
     if is_meta_key(key):
         return key[2:-2]
     else:
         raise ValueError(f'{key} is not a meta key.')
 
 
-def meta_name_to_key(name):
+def meta_name_to_key(name: str) -> str:
     return '__' + name + '__'
 
 
@@ -52,8 +52,10 @@ class DataDictBase(dict):
     def __init__(self, **kw):
         super().__init__(self, **kw)
 
-    def __eq__(self, other: 'DataDictBase'):
+    def __eq__(self, other: object) -> bool:
         """Check for content equality of two datadicts."""
+        if not isinstance(other, DataDictBase):
+            return NotImplemented
 
         if not self.same_structure(self, other):
             # print('structure')
@@ -117,15 +119,15 @@ class DataDictBase(dict):
     # Assignment and retrieval of data and meta data
 
     @staticmethod
-    def _is_meta_key(key):
+    def _is_meta_key(key: str) -> bool:
         return is_meta_key(key)
 
     @staticmethod
-    def _meta_key_to_name(key):
+    def _meta_key_to_name(key: str) -> str:
         return meta_key_to_name(key)
 
     @staticmethod
-    def _meta_name_to_key(name):
+    def _meta_name_to_key(name: str) -> str:
         return meta_name_to_key(name)
 
     def data_items(self) -> Iterator[Tuple[str, Dict[str, Any]]]:
@@ -205,7 +207,7 @@ class DataDictBase(dict):
         else:
             return self[data][k]
 
-    def add_meta(self, key: str, value: Any, data: Union[str, None] = None):
+    def add_meta(self, key: str, value: Any, data: Union[str, None] = None) -> None:
         """
         Add meta info to the dataset.
 
@@ -225,7 +227,7 @@ class DataDictBase(dict):
 
     set_meta = add_meta
 
-    def delete_meta(self, key, data=None):
+    def delete_meta(self, key: str, data: Union[str, None] = None) -> None:
         """
         Remove meta data.
 
@@ -240,7 +242,7 @@ class DataDictBase(dict):
         else:
             del self[data][key]
 
-    def clear_meta(self, data: Union[str, None] = None):
+    def clear_meta(self, data: Union[str, None] = None) -> None:
         """
         Delete meta information.
 
@@ -348,7 +350,7 @@ class DataDictBase(dict):
 
     def structure(self, add_shape: bool = False,
                   include_meta: bool = True,
-                  same_type: bool = False) -> 'DataDictBase':
+                  same_type: bool = False) -> Optional['DataDictBase']:
         """
         Get the structure of the DataDict.
 
@@ -384,8 +386,9 @@ class DataDictBase(dict):
                 s = self.__class__(**s)
 
             return s
+        return None
 
-    def label(self, name: str) -> str:
+    def label(self, name: str) -> Optional[str]:
         """
         Get a label for a data field.
 
@@ -404,6 +407,7 @@ class DataDictBase(dict):
                 n += ' ({})'.format(self[name]['unit'])
 
             return n
+        return None
 
     def axes_are_compatible(self) -> bool:
         """
@@ -422,7 +426,7 @@ class DataDictBase(dict):
                     return False
         return True
 
-    def axes(self, data: Union[str, None] = None) -> List[str]:
+    def axes(self, data: Union[Sequence[str], str, None] = None) -> List[str]:
         """
         Return a list of axes.
 
@@ -439,8 +443,10 @@ class DataDictBase(dict):
                             lst.append(n)
         else:
             if isinstance(data, str):
-                data = [data]
-            for n in data:
+                dataseq: Sequence[str] = (data,)
+            else:
+                dataseq = data
+            for n in dataseq:
                 if 'axes' not in self[n]:
                     continue
                 for m in self[n]['axes']:
@@ -477,7 +483,7 @@ class DataDictBase(dict):
 
     # validation and sanitizing
 
-    def validate(self):
+    def validate(self) -> bool:
         """
         Check the validity of the dataset.
 
@@ -559,7 +565,7 @@ class DataDictBase(dict):
     # axes order tools
 
     def reorder_axes_indices(self, name: str,
-                             **pos: int) -> Tuple[Tuple[int], List[str]]:
+                             **pos: int) -> Tuple[Tuple[int, ...], List[str]]:
         """
         Get the indices that can reorder axes in a given way.
 
@@ -667,7 +673,7 @@ class DataDict(DataDictBase):
         """
 
         # FIXME: remove shape
-        s = self.structure(add_shape=False)
+        s = misc.unwrap_optional(self.structure(add_shape=False))
         if DataDictBase.same_structure(self, newdata):
             for k, v in self.data_items():
                 val0 = self[k]['values']
@@ -681,7 +687,7 @@ class DataDict(DataDictBase):
         else:
             raise ValueError('Incompatible data structures.')
 
-    def append(self, newdata):
+    def append(self, newdata: "DataDict") -> None:
         """
         Append a datadict to this one by appending data values.
 
@@ -707,7 +713,7 @@ class DataDict(DataDictBase):
         for k, v in newvals.items():
             self[k]['values'] = v
 
-    def add_data(self, **kw: Sequence):
+    def add_data(self, **kw: Sequence) -> None:
         # TODO: fill non-given data with nan or none
         """
         Add data to all values. new data must be valid in itself.
@@ -718,7 +724,7 @@ class DataDict(DataDictBase):
         :param kw: one array per data field (none can be omitted).
         :return: None
         """
-        dd = self.structure(same_type=True)
+        dd = misc.unwrap_optional(self.structure(same_type=True))
         for k, v in kw.items():
             if isinstance(v, list):
                 dd[k]['values'] = np.array(v)
@@ -731,21 +737,22 @@ class DataDict(DataDictBase):
             if self.nrecords() > 0:
                 self.append(dd)
             else:
-                for k, v in dd.data_items():
-                    self[k]['values'] = v['values']
+                for key, val in dd.data_items():
+                    self[key]['values'] = val['values']
             self.validate()
 
     # shape information and expansion
 
-    def nrecords(self) -> int:
+    def nrecords(self) -> Optional[int]:
         """
         :return: The number of records in the dataset.
         """
         self.validate()
         for _, v in self.data_items():
             return len(v['values'])
+        return None
 
-    def _inner_shapes(self) -> Dict[str, Tuple[int]]:
+    def _inner_shapes(self) -> Dict[str, Tuple[int, ...]]:
         shapes = self.shapes()
         return {k: v[1:] for k, v in shapes.items()}
 
@@ -796,7 +803,8 @@ class DataDict(DataDictBase):
         self.validate()
         if not self.is_expandable():
             raise ValueError('Data cannot be expanded.')
-        ret = DataDict(**self.structure(add_shape=False))
+        struct = misc.unwrap_optional(self.structure(add_shape=False))
+        ret = DataDict(**struct)
 
         if self.is_expanded():
             return self.copy()
@@ -961,7 +969,7 @@ class MeshgridDataDict(DataDictBase):
     The function ``datadict_to_meshgrid`` provides options for that.
     """
 
-    def shape(self) -> Union[None, Tuple[int]]:
+    def shape(self) -> Union[None, Tuple[int, ...]]:
         """
         Return the shape of the meshgrid.
 
@@ -1047,7 +1055,7 @@ class MeshgridDataDict(DataDictBase):
 # Tools for converting between different data types
 
 def guess_shape_from_datadict(data: DataDict) -> \
-        Dict[str, Union[None, Tuple[List[str], Tuple[int]]]]:
+        Dict[str, Union[None, Tuple[List[str], Tuple[int, ...]]]]:
     """
     Try to guess the shape of the datadict dependents from the axes values.
 
@@ -1117,7 +1125,7 @@ def datadict_to_meshgrid(data: DataDict,
         inner_axis_order, target_shape = ret
 
     # construct new data
-    newdata = MeshgridDataDict(**data.structure(add_shape=False))
+    newdata = MeshgridDataDict(**misc.unwrap_optional(data.structure(add_shape=False)))
     axlist = data.axes(data.dependents()[0])
 
     for k, v in data.data_items():
@@ -1144,7 +1152,7 @@ def meshgrid_to_datadict(data: MeshgridDataDict) -> DataDict:
     :param data: input ``MeshgridDataDict``
     :return: flattened ``DataDict``
     """
-    newdata = DataDict(**data.structure(add_shape=False))
+    newdata = DataDict(**misc.unwrap_optional(data.structure(add_shape=False)))
     for k, v in data.data_items():
         val = v['values'].copy().reshape(-1)
         newdata[k]['values'] = val
