@@ -22,7 +22,7 @@ from typing import Any, Union, Optional, List
 import numpy as np
 import h5py
 
-from plottr import QtGui, Signal, Slot
+from plottr import QtGui, Signal, Slot, QtWidgets
 
 from ..node import (
     Node, NodeWidget, updateOption, updateGuiFromNode,
@@ -127,7 +127,7 @@ def init_path(filepath: str):
 
 
 def datadict_to_hdf5(datadict: DataDict,
-                     basepath: str = None,
+                     basepath: str,
                      groupname: str = 'data',
                      append_mode: AppendMode = AppendMode.new,
                      swmr_mode: bool = True):
@@ -387,9 +387,9 @@ class DDH5LoaderWidget(NodeWidget):
     def __init__(self, node: Node = None):
         super().__init__(node=node)
 
-        self.fileinput = QtGui.QLineEdit()
-        self.groupinput = QtGui.QLineEdit('data')
-        self.reload = QtGui.QPushButton('Reload')
+        self.fileinput = QtWidgets.QLineEdit()
+        self.groupinput = QtWidgets.QLineEdit('data')
+        self.reload = QtWidgets.QPushButton('Reload')
 
         self.optSetters = {
             'filepath': self.fileinput.setText,
@@ -400,11 +400,11 @@ class DDH5LoaderWidget(NodeWidget):
             'groupname': self.groupinput.text,
         }
 
-        flayout = QtGui.QFormLayout()
+        flayout = QtWidgets.QFormLayout()
         flayout.addRow('File path:', self.fileinput)
         flayout.addRow('Group:', self.groupinput)
 
-        vlayout = QtGui.QVBoxLayout()
+        vlayout = QtWidgets.QVBoxLayout()
         vlayout.addLayout(flayout)
         vlayout.addWidget(self.reload)
 
@@ -428,7 +428,6 @@ class DDH5Loader(Node):
 
     def __init__(self, name: str):
         self._filepath = None
-        self._groupname = None
 
         super().__init__(name)
 
@@ -439,7 +438,7 @@ class DDH5Loader(Node):
     def filepath(self):
         return self._filepath
 
-    @filepath.setter
+    @filepath.setter  # type: ignore[misc]
     @updateOption('filepath')
     def filepath(self, val):
         self._filepath = val
@@ -448,7 +447,7 @@ class DDH5Loader(Node):
     def groupname(self):
         return self._groupname
 
-    @groupname.setter
+    @groupname.setter  # type: ignore[misc]
     @updateOption('groupname')
     def groupname(self, val):
         self._groupname = val
