@@ -10,8 +10,8 @@ import numpy as np
 
 from .node import Node, updateOption, NodeWidget
 from ..data.datadict import MeshgridDataDict, DataDict, DataDictBase
-from .. import QtGui, QtCore
-from plottr.icons import xySelectIcon
+from .. import QtCore, QtWidgets, Signal, Slot
+from plottr.icons import get_xySelectIcon
 
 __author__ = 'Wolfgang Pfaff'
 __license__ = 'MIT'
@@ -61,7 +61,7 @@ reductionFunc = {
     ReductionMethod.average: np.mean,
 }
 
-class DimensionAssignmentWidget(QtGui.QTreeWidget):
+class DimensionAssignmentWidget(QtWidgets.QTreeWidget):
     """
     A Widget that allows to assign options ('roles') to dimensions of a
     dataset.
@@ -69,7 +69,7 @@ class DimensionAssignmentWidget(QtGui.QTreeWidget):
     This needs to be done by inheriting classes.
     """
 
-    rolesChanged = QtCore.pyqtSignal(object)
+    rolesChanged = Signal(object)
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -151,10 +151,10 @@ class DimensionAssignmentWidget(QtGui.QTreeWidget):
 
         :param name: name of the dimension.
         """
-        item = QtGui.QTreeWidgetItem([name, '', '', ''])
+        item = QtWidgets.QTreeWidgetItem([name, '', '', ''])
         self.addTopLevelItem(item)
 
-        combo = QtGui.QComboBox()
+        combo = QtWidgets.QComboBox()
         for t, opts in self.availableChoices.items():
             if t == self._dataType or issubclass(self._dataType, t):
                 for o in opts:
@@ -218,14 +218,14 @@ class DimensionAssignmentWidget(QtGui.QTreeWidget):
                 'options' : {},
             }
 
-    def getRole(self, name: str) -> Tuple[str, Any]:
+    def getRole(self, name: str) -> Tuple[str, Dict]:
         """
         Get the current role and its options for a dimension.
         :param name: 
         :return: 
         """
         role = self.choices[name]['roleSelectionWidget'].currentText()
-        opts = {}
+        opts: Dict = {}
         return role, opts
 
     def getRoles(self) -> Dict[str, Dict[str, Any]]:
@@ -242,7 +242,7 @@ class DimensionAssignmentWidget(QtGui.QTreeWidget):
             }
         return ret
 
-    @QtCore.pyqtSlot(str, str)
+    @Slot(str, str)
     def setDimInfo(self, dim: str, info: str = ''):
         try:
             item = self.findItems(dim, QtCore.Qt.MatchExactly, 0)[0]
@@ -250,7 +250,7 @@ class DimensionAssignmentWidget(QtGui.QTreeWidget):
         except IndexError:
             pass
 
-    @QtCore.pyqtSlot(dict)
+    @Slot(dict)
     def setDimInfos(self, infos: Dict[str, str]):
         for ax, info in infos.items():
             self.setInfo(ax, info)
@@ -304,13 +304,13 @@ class DimensionReductionAssignmentWidget(DimensionAssignmentWidget):
             self._setElementSelectionInfo(dim)
 
     def elementSelectionSlider(self, nvals: int, value: int = 0):
-        w = QtGui.QSlider(0x01)
+        w = QtWidgets.QSlider(QtCore.Qt.Horizontal)
         w.setMinimum(0)
         w.setMaximum(nvals - 1)
         w.setSingleStep(1)
         w.setPageStep(1)
         w.setTickInterval(max(1, nvals//10))
-        w.setTickPosition(QtGui.QSlider.TicksBelow)
+        w.setTickPosition(QtWidgets.QSlider.TicksBelow)
         w.setValue(value)
         return w
 
@@ -351,7 +351,7 @@ class DimensionReducerNodeWidget(NodeWidget):
 
     def __init__(self, node: Node = None):
         super().__init__(embedWidgetClass=DimensionReductionAssignmentWidget)
-
+        assert self.widget is not None
         self.optSetters = {
             'reductions': self.setReductions,
         }
@@ -420,7 +420,7 @@ class DimensionReducer(Node):
 
     #: A signal that emits (structure, shapes, type) when data structure has
     #: changed.
-    newDataStructure = QtCore.pyqtSignal(object, object, object)
+    newDataStructure = Signal(object, object, object)
 
     def __init__(self, *arg, **kw):
         self._reductions = {}
@@ -435,7 +435,7 @@ class DimensionReducer(Node):
     def reductions(self):
         return self._reductions
 
-    @reductions.setter
+    @reductions.setter  # type: ignore[misc]
     @updateOption('reductions')
     def reductions(self, val):
         self._reductions = val
@@ -444,7 +444,7 @@ class DimensionReducer(Node):
     def targetNames(self):
         return self._targetNames
 
-    @targetNames.setter
+    @targetNames.setter  # type: ignore[misc]
     @updateOption()
     def targetNames(self, val):
         self._targetNames = val
@@ -599,10 +599,10 @@ class DimensionReducer(Node):
 
 class XYSelectorNodeWidget(NodeWidget):
 
-    icon = xySelectIcon
-
     def __init__(self, node: Node = None):
+        self.icon = get_xySelectIcon()
         super().__init__(embedWidgetClass=XYSelectionWidget)
+        assert self.widget is not None
 
         self.optSetters = {
             'dimensionRoles': self.setRoles,
@@ -669,7 +669,7 @@ class XYSelector(DimensionReducer):
     def xyAxes(self):
         return self._xyAxes
 
-    @xyAxes.setter
+    @xyAxes.setter  # type: ignore[misc]
     @updateOption('xyAxes')
     def xyAxes(self, val):
         self._xyAxes = val
@@ -685,7 +685,7 @@ class XYSelector(DimensionReducer):
             dr[dim] = red
         return dr
 
-    @dimensionRoles.setter
+    @dimensionRoles.setter  # type: ignore[misc]
     @updateOption('dimensionRoles')
     def dimensionRoles(self, val):
         xy = [None, None]
