@@ -7,10 +7,10 @@ import traceback
 from logging import Logger
 
 from functools import wraps
-from typing import Any, Union, Tuple, Dict
+from typing import Any, Union, Tuple, Dict, Optional, Type, List
 
 from .. import NodeBase
-from .. import QtGui, QtCore, Signal, Slot
+from .. import QtGui, QtCore, Signal, Slot, QtWidgets
 from ..data.datadict import DataDictBase, MeshgridDataDict
 from .. import log
 
@@ -111,7 +111,7 @@ class Node(NodeBase):
 
     #: UI node widget class. If not None, and ``useUi`` is ``True``, an
     #: instance of the widget is created, and signal/slots are connected.
-    uiClass = None
+    uiClass: Optional[Type["NodeWidget"]] = None
 
     #: Whether or not to automatically set up a UI widget.
     useUi = True
@@ -121,7 +121,7 @@ class Node(NodeBase):
 
     #: A signal to notify the UI of option changes
     #: arguments is a dictionary of options and new values.
-    optionChangeNotification = QtCore.pyqtSignal(dict)
+    optionChangeNotification = Signal(dict)
 
     #: signal emitted when available data axes change
     #: emits a the list of names of new axes
@@ -141,7 +141,7 @@ class Node(NodeBase):
     dataShapesChanged = Signal(dict)
 
     #: when data structure changes, emits (structure, shapes, type)
-    newDataStructure = QtCore.pyqtSignal(object, object, object)
+    newDataStructure = Signal(object, object, object)
 
     #: developer flag for whether we actually want to raise of use the logging
     #: system
@@ -155,14 +155,14 @@ class Node(NodeBase):
         super().__init__(name, terminals=self.__class__.terminals)
 
         self.signalUpdate = True
-        self.dataAxes = None
-        self.dataDependents = None
-        self.dataType = None
-        self.dataShapes = None
-        self.dataStructure = None
+        self.dataAxes: Optional[List[str]] = None
+        self.dataDependents: Optional[List[str]] = None
+        self.dataType: Optional[Type[DataDictBase]] = None
+        self.dataShapes: Optional[Dict[str, Tuple[int, ...]]] = None
+        self.dataStructure: Optional[DataDictBase] = None
 
         if self.useUi and self.__class__.uiClass is not None:
-            self.ui = self.__class__.uiClass(node=self)
+            self.ui: Optional["NodeWidget"] = self.__class__.uiClass(node=self)
             self.setupUi()
         else:
             self.ui = None
@@ -181,7 +181,7 @@ class Node(NodeBase):
         self.ui.allOptionsToNode.connect(self.setOptions)
         self.optionChangeNotification.connect(self.ui.setOptionsFromNode)
 
-    def ctrlWidget(self) -> Union[QtGui.QWidget, None]:
+    def ctrlWidget(self) -> Union[QtWidgets.QWidget, None]:
         """Returns the node widget, if it exists.
         """
         return self.ui
@@ -310,7 +310,7 @@ class Node(NodeBase):
         return dict(dataOut=dataIn)
 
 
-class NodeWidget(QtGui.QWidget):
+class NodeWidget(QtWidgets.QWidget):
     """
     Base class for Node control widgets.
 
@@ -327,25 +327,26 @@ class NodeWidget(QtGui.QWidget):
 
     #: signal (args: object)) to emit to notify the node of a (changed)
     #: user option.
-    optionToNode = QtCore.pyqtSignal(object)
+    optionToNode = Signal(object)
 
     #: signal (args: (object)) all options to the node.
-    allOptionsToNode = QtCore.pyqtSignal(object)
+    allOptionsToNode = Signal(object)
 
-    def __init__(self, parent: QtGui.QWidget = None,
-                 embedWidgetClass: QtGui.QWidget = None,
+    def __init__(self, parent: QtWidgets.QWidget = None,
+                 embedWidgetClass: Type[QtWidgets.QWidget] = None,
                  node: Node = None):
         super().__init__(parent)
 
-        self.optGetters = {}
-        self.optSetters = {}
+        self.optGetters: Dict[str, Any] = {}
+        self.optSetters: Dict[str, Any] = {}
         self.node = node
 
         self._emitGuiChange = True
 
-        self.widget = None
+        self.widget: Optional[QtWidgets.QWidget] = None
+
         if embedWidgetClass is not None:
-            layout = QtGui.QVBoxLayout()
+            layout = QtWidgets.QVBoxLayout()
             layout.setContentsMargins(0, 0, 0, 0)
             self.widget = embedWidgetClass()
             layout.addWidget(self.widget)
@@ -371,7 +372,7 @@ class NodeWidget(QtGui.QWidget):
         """
         self.optSetters[opt](value)
 
-    @QtCore.pyqtSlot(dict)
+    @Slot(dict)
     def setOptionsFromNode(self, opts: Dict[str, Any]):
         """Set all options without triggering updates back to the node."""
         for opt, val in opts.items():
