@@ -5,7 +5,7 @@ plottr/plot/mpl.py : Tools for plotting with matplotlib.
 import logging
 import io
 from enum import Enum, unique, auto
-from typing import Dict, List, Tuple, Union
+from typing import Dict, List, Tuple, Union, cast, Optional
 from collections import OrderedDict
 
 # standard scientific computing imports
@@ -21,13 +21,13 @@ from matplotlib.figure import Figure
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 
 from .base import PlotWidget
-from .. import QtGui, QtCore, Signal, Slot
+from .. import QtGui, QtCore, Signal, Slot, QtWidgets
 from ..utils import num
 from ..utils.num import interp_meshgrid_2d, centers2edges_2d
 from ..data.datadict import DataDictBase, DataDict, MeshgridDataDict
 
-from plottr.icons import (singleTracePlotIcon, multiTracePlotIcon, imagePlotIcon,
-                          colormeshPlotIcon, scatterPlot2dIcon)
+from plottr.icons import (get_singleTracePlotIcon, get_multiTracePlotIcon, get_imagePlotIcon,
+                          get_colormeshPlotIcon, get_scatterPlot2dIcon)
 
 
 __author__ = 'Wolfgang Pfaff'
@@ -101,7 +101,7 @@ class ComplexRepresentation(Enum):
     magAndPhase = auto()
 
 
-def determinePlotDataType(data: DataDictBase) -> PlotDataType:
+def determinePlotDataType(data: Optional[DataDictBase]) -> PlotDataType:
     """
     Analyze input data and determine most likely :class:`PlotDataType`.
 
@@ -369,7 +369,7 @@ def plot1dTrace(ax: Axes, x: np.ndarray, y: np.ndarray,
 
     plot_kw = dict(lw=1, mew=1, mfc='w')
     plot_kw.update(kw)
-    fmt = plot_kw.pop('fmt', 'o-')
+    fmt = cast(str, plot_kw.pop('fmt', 'o-'))
 
     # if we're plotting real and imaginary parts, modify the label
     lbl = None
@@ -408,7 +408,7 @@ class MPLPlot(FCanvas):
     It can be used as any QT widget.
     """
 
-    def __init__(self, parent: QtGui.QWidget = None, width: float = 4.0,
+    def __init__(self, parent: QtWidgets.QWidget = None, width: float = 4.0,
                  height: float = 3.0, dpi: int = 150, nrows: int = 1,
                  ncols: int = 1):
         """
@@ -425,7 +425,7 @@ class MPLPlot(FCanvas):
         self.fig = Figure(figsize=(width, height), dpi=dpi)
         super().__init__(self.fig)
 
-        self.axes = []
+        self.axes: List[Axes] = []
         self._tightLayout = False
         self._showInfo = False
         self._infoArtist = None
@@ -521,7 +521,7 @@ class MPLPlot(FCanvas):
         buf = io.BytesIO()
         self.fig.savefig(buf, dpi=300, facecolor='w', format='png',
                          transparent=True)
-        QtGui.QApplication.clipboard().setImage(
+        QtWidgets.QApplication.clipboard().setImage(
             QtGui.QImage.fromData(buf.getvalue()))
         buf.close()
 
@@ -567,7 +567,7 @@ class _MPLPlotWidget(PlotWidget):
         self.addMplBarOptions()
         self.mplBar.setIconSize(QtCore.QSize(16,16))
 
-        self.layout = QtGui.QVBoxLayout(self)
+        self.layout = QtWidgets.QVBoxLayout(self)
         self.layout.addWidget(self.plot)
         self.layout.addWidget(self.mplBar)
 
@@ -579,10 +579,10 @@ class _MPLPlotWidget(PlotWidget):
             self.plot.setFigureInfo(data.meta_val('info'))
 
     def addMplBarOptions(self):
-        tlCheck = QtGui.QCheckBox('Tight layout')
+        tlCheck = QtWidgets.QCheckBox('Tight layout')
         tlCheck.toggled.connect(self.plot.setTightLayout)
 
-        infoCheck = QtGui.QCheckBox('Info')
+        infoCheck = QtWidgets.QCheckBox('Info')
         infoCheck.toggled.connect(self.plot.setShowInfo)
 
         self.mplBar.addSeparator()
@@ -594,7 +594,7 @@ class _MPLPlotWidget(PlotWidget):
 
 
 # A toolbar for setting options on the MPL autoplot
-class _AutoPlotToolBar(QtGui.QToolBar):
+class _AutoPlotToolBar(QtWidgets.QToolBar):
     """
     A toolbar that allows the user to configure AutoPlot.
 
@@ -609,18 +609,18 @@ class _AutoPlotToolBar(QtGui.QToolBar):
     complexPolarSelected = Signal(bool)
 
 
-    def __init__(self, name: str, parent: QtGui.QWidget = None):
+    def __init__(self, name: str, parent: QtWidgets.QWidget = None):
         """Constructor for :class:`AutoPlotToolBar`"""
 
         super().__init__(name, parent=parent)
 
-        self.plotasMultiTraces = self.addAction(multiTracePlotIcon,
+        self.plotasMultiTraces = self.addAction(get_multiTracePlotIcon(),
                                                 'Multiple traces')
         self.plotasMultiTraces.setCheckable(True)
         self.plotasMultiTraces.triggered.connect(
             lambda: self.selectPlotType(PlotType.multitraces))
 
-        self.plotasSingleTraces = self.addAction(singleTracePlotIcon,
+        self.plotasSingleTraces = self.addAction(get_singleTracePlotIcon(),
                                                  'Individual traces')
         self.plotasSingleTraces.setCheckable(True)
         self.plotasSingleTraces.triggered.connect(
@@ -628,19 +628,19 @@ class _AutoPlotToolBar(QtGui.QToolBar):
 
         self.addSeparator()
 
-        self.plotasImage = self.addAction(imagePlotIcon,
+        self.plotasImage = self.addAction(get_imagePlotIcon(),
                                           'Image')
         self.plotasImage.setCheckable(True)
         self.plotasImage.triggered.connect(
             lambda: self.selectPlotType(PlotType.image))
 
-        self.plotasMesh = self.addAction(colormeshPlotIcon,
+        self.plotasMesh = self.addAction(get_colormeshPlotIcon(),
                                          'Color mesh')
         self.plotasMesh.setCheckable(True)
         self.plotasMesh.triggered.connect(
             lambda: self.selectPlotType(PlotType.colormesh))
 
-        self.plotasScatter2d = self.addAction(scatterPlot2dIcon,
+        self.plotasScatter2d = self.addAction(get_scatterPlot2dIcon(),
                                               'Scatter 2D')
         self.plotasScatter2d.setCheckable(True)
         self.plotasScatter2d.triggered.connect(
@@ -662,7 +662,7 @@ class _AutoPlotToolBar(QtGui.QToolBar):
         })
 
         self._currentPlotType = PlotType.empty
-        self._currentlyAllowedPlotTypes = []
+        self._currentlyAllowedPlotTypes: Tuple[PlotType, ...] = ()
 
     def selectPlotType(self, plotType: PlotType):
         """makes sure that the selected `plotType` is active (checked), all
@@ -779,7 +779,7 @@ class AutoPlot(_MPLPlotWidget):
 
         self.setMinimumSize(640, 480)
 
-    def _analyzeData(self, data: DataDictBase) -> Dict[str, bool]:
+    def _analyzeData(self, data: Optional[DataDictBase]) -> Dict[str, bool]:
         """checks data and compares with previous properties."""
         dataType = type(data)
 
@@ -827,7 +827,7 @@ class AutoPlot(_MPLPlotWidget):
 
         return False
 
-    def setData(self, data: DataDictBase):
+    def setData(self, data: Optional[DataDictBase]):
         """Analyses data and determines whether/what to plot.
 
         :param data: input data
@@ -876,12 +876,12 @@ class AutoPlot(_MPLPlotWidget):
 
         self._plotData(adjustSize=True)
 
-    def _makeAxes(self, nAxes: int) -> Axes:
+    def _makeAxes(self, nAxes: int) -> List[Axes]:
         """Create a grid of axes.
         We try to keep the grid as square as possible.
         """
         nrows = int(nAxes ** .5 + .5)
-        ncols = np.ceil(nAxes / nrows)
+        ncols = int(np.ceil(nAxes / nrows))
         axes = self.plot.clearFig(nrows, ncols, nAxes)
         return axes
 
